==> haskell-aeson-better-errors-0.9.1.0-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-better-errors
version:              0.9.1.0
visibility:           public
id:                   aeson-better-errors-0.9.1.0-24IjZ9EJdDUIg3Rx7b4l35
key:                  aeson-better-errors-0.9.1.0-24IjZ9EJdDUIg3Rx7b4l35
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  bcee4f7d31522045c88efef5aebaa16f
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-8.10.3/site-local/aeson-better-errors-0.9.1.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/aeson-better-errors-0.9.1.0

hs-libraries:         HSaeson-better-errors-0.9.1.0-24IjZ9EJdDUIg3Rx7b4l35
depends:
    aeson-1.5.5.1-5y8ldlqGOftJjgtSRZKxTs base-4.14.1.0
    bytestring-0.10.12.0 dlist-1.0-6WxLEKqyX4I8XLADNq07GX mtl-2.2.2
    scientific-0.3.6.2-ADhtbFlydoyEO8Nhlpr0e9 text-1.2.4.1
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    unordered-containers-0.2.13.0-5ciSEfPtJAO2lGL3MRiwwP
    vector-0.12.1.2-HCJzCvMeU9f2WjtWVmO7dQ
    void-0.7.3-FJLCa6y31Qt20kSi8TCcBC

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.0-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-better-errors
version:              0.9.1.0
visibility:           public
id:                   aeson-better-errors-0.9.1.0-9dHEqtbZuYEEAhAm2uCata
key:                  aeson-better-errors-0.9.1.0-9dHEqtbZuYEEAhAm2uCata
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  fdd9fbecad17722c8fb5fb0130544417
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-8.10.3/site-local/aeson-better-errors-0.9.1.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/aeson-better-errors-0.9.1.0

hs-libraries:         HSaeson-better-errors-0.9.1.0-9dHEqtbZuYEEAhAm2uCata
depends:
    aeson-1.5.5.1-E81o7ZLeKZ2F33ZL69kpyr base-4.14.1.0
    bytestring-0.10.12.0 dlist-1.0-8lf2wgAIOQZ603aeYRXCBo mtl-2.2.2
    scientific-0.3.6.2-IVJaYC1OFEPDndVZtBH1Ry text-1.2.4.1
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    unordered-containers-0.2.13.0-D33WFZMtrpm4EjBHW4MnLA
    vector-0.12.1.2-H4eLF7dv8NOKyZpgYZDRLA
    void-0.7.3-FJLCa6y31Qt20kSi8TCcBC

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
